<?php
class WPuser
{
    private $WPTableTitlePhone;
    private $WPTableTitleActivationCode;
    private $WPTableTitleRegisteredDate;

    // Setters
    public function setWPTableTitlePhone($usersMobile)
    {
        $this->WPTableTitlePhone = $usersMobile;
    }
    public function setWPTableTitleActivationCode($usersActivation)
    {
        $this->WPTableTitleActivationCode = $usersActivation;
    }
    public function setWPTableTitleRegisteredDate($registeredDate)
    {
        $this->WPTableTitleRegisteredDate = $registeredDate;
    }

    public function addSetup()
    {
        // Actions
        add_action('edit_user_profile_update', array(&$this, 'brOTP_update_phonenumber_field'));
        add_action('personal_options_update', array(&$this, 'brOTP_update_phonenumber_field'));
        add_action('user_register', array(&$this, 'brOTP_update_phonenumber_field'));

        add_action('edit_user_profile', array(&$this, 'brOTP_add_phonenumber_field'));
        add_action('show_user_profile', array(&$this, 'brOTP_add_phonenumber_field'));

        add_action('user_new_form', array(&$this, 'brOTP_add_phonenumber_field_to_new_form'));

        // Filters
        add_filter('manage_users_columns', array(&$this, 'brOTP_modify_user_table'));
        add_filter('manage_users_custom_column', array(&$this, 'brOTP_modify_user_table_row'), 10, 3);
        add_filter('manage_users_sortable_columns',  array(&$this, 'brOTP_make_registered_date_column_sortable'));
    }



    // ====================================================================
    // ACTION FUNCTION
    // ====================================================================

    // UPDATE PHONE NUMBER FIELD
    function brOTP_update_phonenumber_field($user_id)
    {
        if (!current_user_can('edit_user', $user_id)) {
            return false;
        }
        update_user_meta($user_id, 'phone_number', $_POST['phone_number']);
    }

    // ADD PHONE NUMBER FIELD IN NEW FORM
    function brOTP_add_phonenumber_field_to_new_form($user)
    {
        //$phn = get_the_author_meta('phone_number', $user->ID)
?>
        <h3><?php esc_html_e('Personal Information', 'crf'); ?></h3>

        <table class="form-table">
            <tr>
                <th><label for="phone_number"><?php esc_html_e('phone_number', "otp-login"); ?></label></th>
                <td>
                    <input type="text" id="phone_number" name="phone_number" value="" class="regular-text" />
                </td>
            </tr>
        </table>
    <?php
    }

    // ADD PHONE NUMBER FIELD
    function brOTP_add_phonenumber_field($user)
    {
        $phn = get_the_author_meta('phone_number', $user->ID);
    ?>
        <h3><?php esc_html_e('Personal Information', 'crf'); ?></h3>

        <table class="form-table">
            <tr>
                <th><label for="phone_number"><?php esc_html_e('phone_number', "otp-login"); ?></label></th>
                <td>
                    <input type="text" step="1" id="phone_number" name="phone_number" value="<?php echo esc_attr($phn); ?>" class="regular-text" />

                </td>
            </tr>
        </table>
<?php
    }

    // ====================================================================
    // FILTER FUNCTIONS
    // ====================================================================

    // MODIFY USER TABLE
    function brOTP_modify_user_table($column)
    {
        $column['phone_number'] = __($this->WPTableTitlePhone, "otp-login");
        $column['activation_code'] = __($this->WPTableTitleActivationCode, "otp-login");
        $column['registered_date'] = __($this->WPTableTitleRegisteredDate, "otp-login");
        return $column;
    }

    // MODIFY USER TABLE ROW
    function brOTP_modify_user_table_row($val, $column_name, $user_id)
    {
        $udata = get_userdata($user_id);
        switch ($column_name) {
            case 'phone_number':
                return get_the_author_meta('phone_number', $user_id);
            case 'activation_code':
                return get_the_author_meta('activation_code', $user_id);
            case 'registered_date':
                return $udata->user_registered;
            default:
        }
        return $val;
    }

    // MAKE REGISTERED DATE COLUMN SORTABE
    function brOTP_make_registered_date_column_sortable($columns)
    {
        return wp_parse_args(array('registered_date' => 'registered'), $columns);
    }
}

$user = new WPuser();
$user->setWPTableTitlePhone('Phone number');
$user->setWPTableTitleActivationCode('Activation code');
$user->setWPTableTitleRegisteredDate('Registered Date');

$user->addSetup();
